{ pkgs-local, pkgs-stable, inputs, pkgs, ... }:
{

  home.packages = with pkgs; [
    inputs.isd.packages.x86_64-linux.default

    razer-cli

    goimapnotify

    cmake
    cmake-format

    mediainfo
    gtrash

    just
    readline
    rlwrap
    yt-dlp
    age
    figlet
    ffmpeg-full
    ouch
    pinentry
    gcr
    gnutar
    libnotify
    unzip
    zip
    tldr
    pkgs-stable.rich-cli
    gnupg
    imagemagick

    nix-du
    nix-melt
    nix-tree

    usbutils
    pciutils
    util-linux
    coreutils
    binutils
    editorconfig-core-c
    exiftool
    libsecret
    shellcheck

    icloudpd
    pkg-config

    numbat
    nix-converter
    nurl
    fastfetch
    nvd
    ripgrep-all
    silver-searcher

    age
    manix
    caligula

    rink

    dua
    bluetui

    tree
    emoji-picker

    sox
    imgcat
    ghostscript
    playerctl
    tesseract
    dockfmt
    trash-cli
    poppler_utils

    fishPlugins.foreign-env
    fishPlugins.fzf-fish
    fishPlugins.bass
    fishPlugins.autopair
    fishPlugins.forgit
    fishPlugins.colored-man-pages

    television
  ];

  programs = {
    # bash = {
    #   enable = true;
    # };
    nix-index = {
      enable = true;
      enableFishIntegration = true;
    };
    direnv = {
      enable = true;
      nix-direnv.enable = true;
      config = {
        whitelist = {
          prefix = [ "~/source" "~/projects" ];
        };
      };
    };
    fish = {
      enable = true;
      shellAliases = {
        "em" = "emacsclient -n -r";
        "mkdir" = "mkdir -pv";
        "gt" = "gtrash";
        "rm" = "gtrash put";
      };

      # change fzf variable search to C-M-v
      interactiveShellInit = ''
      bind --erase \ct
      fzf_configure_bindings --variables=\e\cv
      '';

      plugins = [
        {
          name = "upto";
          src = pkgs.fetchFromGitHub {
            owner = "Markcial";
            repo = "upto";
            rev = "2d1f35453fb55747d50da8c1cb1809840f99a646";
            sha256 = "sha256-Lv2XtP2x9dkIkUUjMBWVpAs/l55Ztu7gIjKYH6ZzK4s=";
          };
        }
      ];
    };
    zoxide = {
      enableFishIntegration = true;
      enableBashIntegration = true;
      enable = true;
    };
    starship = {
      enableFishIntegration = true;
      enableBashIntegration = true;
      enable = true;
    };
    ripgrep = {
      enable = true;
      package = (pkgs.ripgrep.override {withPCRE2 = true;});
    };
    ghostty = {
      enable = true;
      # settings = {
      #   theme = "";
      # };
    };
    wezterm = {
      enable = true;
      enableBashIntegration = true;
      package = inputs.wezterm.packages.${pkgs.system}.default;
    };
    bat = {
      enable = true;
    };
    eza = {
      enable = true;
      enableFishIntegration = true;
      enableBashIntegration = true;
      git = true;
      icons = "auto";
      colors = "auto";
    };
    fd = {
      enable = true;
    };
    fzf = {
      enable = true;
      # enableFishIntegration = false;
      # enableBashIntegration = true;
    };
    broot = {
      enable = true;
    };
    lazygit = {
      enable = true;
      settings = {
        nerdFontsVersion = "3";
        git = {
          paging.pager = "delta --paging=never";
        };
      };
    };
    jq.enable = true;
    rbw = {
      enable = true;
      package = pkgs-local.rbw-latest;
    };
  };

  xdg.configFile."starship.toml".source = ./shell-conf/starship/starship.toml;
  xdg.configFile."wezterm" = {
    recursive = true;
    source = ./shell-conf/wezterm;
  };

  xdg.configFile."rbw".source = ./shell-conf/rbw;
  xdg.configFile."isd_tui/config.yaml".source = ./shell-conf/isd_tui/config.yaml;

  home.file.".config/fish/functions" = {
    source = ./shell-conf/fish/functions;
    recursive = true;
  };

  home.file.".config/fish/completions" = {
    source = ./shell-conf/fish/completions;
    recursive = true;
  };

  home.file.".local/share/flf".source = ./shell-conf/flf;

}
